@@ -46,9 +46,7 @@ AttachmentIconItem::AttachmentIconItem(const KCalendarCore::Attachment &att, QLi
     setFlags(flags() | Qt::ItemIsDragEnabled);
 }
 
-AttachmentIconItem::~AttachmentIconItem()
-{
-}
+AttachmentIconItem::~AttachmentIconItem() = default;
 
 KCalendarCore::Attachment AttachmentIconItem::attachment() const
 {
@@ -188,7 +186,11 @@ QUrl AttachmentIconItem::tempFileForAttachment()
     return mTempFile;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 QMimeData *AttachmentIconView::mimeData(const QList<QListWidgetItem *> items) const // clazy:exclude=function-args-by-ref
+#else
+QMimeData *AttachmentIconView::mimeData(const QList<QListWidgetItem *> &items) const // clazy:exclude=function-args-by-ref
+#endif
 {
     // create a list of the URL:s that we want to drag
     QList<QUrl> urls;
